#include <sys/types.h>
#include <sys/socket.h>
#include <netdb.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <poll.h>

void
die(const char *funame)
{
    fprintf(stderr, "%s: %s\n", funame, strerror(errno));
    exit(1);    
}

int
main()
{
    struct addrinfo hints, *res;
    memset(&hints, 0, sizeof hints);
    hints.ai_family = AF_INET;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags = AI_PASSIVE;

    if(getaddrinfo(NULL, "0", &hints, &res) < 0)
	die("getaddrinfo");
    
    int sock = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
    if(sock < 0)
	die("socket");

    if(bind(sock, res->ai_addr, res->ai_addrlen) < 0)
	die("bind");

    if(listen(sock, 5) < 0)
	die("listen");

    struct pollfd fds[1];
    fds[0].fd = sock;
    fds[0].events = POLLOUT;
    if(poll(fds, 1, 0) < 0)
	die("poll");

    // prints out, but shouldn't
    if(fds[0].revents & POLLOUT)
	printf("OUT\n");
    
    return 0;
}
